SuperLU: Data Structures

SuperLU 7.0.1

Data Structures
Here are the data structures with brief descriptions:

C Colamd_Col_struct |
C Colamd_Row_struct |
C DNformat |
C doublecomplex |
C e_node | Headers for 4 types of dynamatically managed memory
C factors_t |
C GlobalLU_t |
C LU_stack_t |
C mem_usage_t |
C NCformat |
C NCPformat |
C NRformat |
C NRformat_loc |
C NRformat_loc3d |
C SCformat |
C SCPformat |
C singlecomplex |
C superlu_options_t |
C SuperLUStat_t |
C SuperMatrix |